@@ -400,6 +400,24 @@ class CloudPods:
             log.error(f"Failed to request /servers/{server_id}/restart: Error.\rerr msg is {str(e)}")
             return False
 
+    @enter_and_leave_function
+    def get_server_status(self,server_id):
+        try:
+            url = self.__compute_url + f"/servers/{server_id}/status"
+            rs = self.__session.get(url=url, verify=False, timeout=600)
+            if rs.status_code != 200:
+                log.warning(f"Failed to request /servers/{server_id}/status: Error. err msg is {str(rs.text)}")
+                return None
+            try:
+                rs_data = rs.json()
+                return rs_data["server"]["status"]
+            except Exception as e:
+                log.warning(f"Failed to request /servers/{server_id}/status: Error. err msg is {str(e)}")
+                return None
+        except Exception as e:
+            log.error(f"Failed to request /servers/{server_id}/status: Error.\rerr msg is {str(e)}")
+            return None
+
     @enter_and_leave_function
     def get_server_ip(self, server_id):
         server = self.get_server_detail(server_id)
@@ -556,15 +574,19 @@ class CloudPods:
     @enter_and_leave_function
     def wait_for_server_is_deleted(self,server_id):
         try:
-            for i in range(600):
-                server_detail = self.get_server_detail(server_id)
-                if server_detail is None:
-                    log.info(f"server_id: {server_id} deleted")
+            for i in range(360):
+                status = self.get_server_status(server_id)
+                if status is None:
+                    log.info(f"server {server_id} has been deleted")
                     return True
-                log.warning(f"server_id: {server_id} is deleting")
+                log.warning(f"server {server_id} status is {status}")
                 time.sleep(5)
-            log.warning(f"Failed to wait for server {server_id} is deleted: Error.\nserver_detail is {server_detail}")
-            return False
+                if i % 10 == 0:
+                    log.info(f"try to delete server {server_id}...")
+                    self.delete_server(server_id)
+            else:
+                log.warning(f"Failed to wait for server {server_id} is deleted and half hour has been passed: Error.\nserver status is {status}")
+                return False
         except Exception as e:
             log.error(f"Failed to wait for server {server_id} is deleted: Error.\rerr msg is {str(e)}",exc_info=True)
             return False
@@ -594,11 +616,15 @@ if __name__ == '__main__':
     # print(server_ip)
     # cloudpods = CloudPods('https://10.240.30.110:30500/v3', 'admin', 'jSj@2008')
     cloudpods = CloudPods('https://10.20.40.101:30500/v3', 'admin', 'jSj@2008')
+    # rs=cloudpods.get_server_status("b43ba471-471a-44c1-8753-a7b8a9ead05c")
+    # print(rs)
+    rs=cloudpods.wait_for_server_is_deleted("fb4b6563-f43e-404b-8b74-394c331eb89b")
+    print(rs)
     # rs=cloudpods.get_baremetal_hosts()
     # print(rs)
     # rs=cloudpods.get_server_detail("8c925c8e-752f-4358-8c3e-a80847732d91")
     # print(rs)
-    rs=cloudpods.restart_server("b868a4fb-05a0-4ca0-804a-acbd4d814ea7")
+    # rs=cloudpods.restart_server("b868a4fb-05a0-4ca0-804a-acbd4d814ea7")
     # print(len(rs["hosts"]))
     # rs=cloudpods.get_baremetal_servers()
     # print(rs)
